@@ -109,7 +109,7 @@ init (GnomePilotCDialog *gpcd)
 	gpcd->priv = priv;
 
 	/* Gui stuff */
-	priv->xml = glade_xml_new (GLADEDATADIR "/gpilotd-capplet.glade", "ConduitSettings");
+	priv->xml = glade_xml_new (GLADEDATADIR "/gpilotd-capplet.glade", "ConduitSettings", NULL);
 	if (!priv->xml) {
 		g_message ("gnome-pilot-cdialog init(): Could not load the Glade XML file!");
 		goto error;
@@ -206,7 +206,7 @@ fill_widgets (GnomePilotCDialog *gpcd)
 
 		} else if (gnome_pilot_conduit_create_settings_window (priv->state->conduit, priv->options_frame) == 500) { /* < 0) { */
 			gchar *msg = _("Unable to create pilot settings window. Incorrect conduit configuration.");
-			error_dialog (msg);
+			error_dialog (GTK_WINDOW (priv->dialog), msg);
 			
 			/* Self healing. Will not try again for this run of the capplet */
 			gnome_pilot_conduit_management_destroy_conduit (priv->state->management, &priv->state->conduit);
@@ -247,13 +247,14 @@ gnome_pilot_cdialog_first_sync_type (GnomePilotCDialog *gpcd)
 }
 
 gboolean
-gnome_pilot_cdialog_run_and_close (GnomePilotCDialog *gpcd)
+gnome_pilot_cdialog_run_and_close (GnomePilotCDialog *gpcd, GtkWindow *parent)
 {
 	GnomePilotCDialogPrivate *priv;
 	gint btn;
 	
 	priv = gpcd->priv;
 	
+	gnome_dialog_set_parent (GNOME_DIALOG (priv->dialog), parent);
 	btn = gnome_dialog_run_and_close (GNOME_DIALOG (priv->dialog));
 
 	return btn == 0 ? TRUE : FALSE;
